@@ -24,6 +24,9 @@
 #ifndef PHP_REDIS_H
 #define PHP_REDIS_H
 
+/* phpredis version */
+#define PHP_REDIS_VERSION "3.1.0"
+
 PHP_METHOD(Redis, __construct);
 PHP_METHOD(Redis, __destruct);
 PHP_METHOD(Redis, connect);
@@ -77,6 +80,7 @@ PHP_METHOD(Redis, lGetRange);
 PHP_METHOD(Redis, lSet);
 PHP_METHOD(Redis, lInsert);
 PHP_METHOD(Redis, sAdd);
+PHP_METHOD(Redis, sAddArray);
 PHP_METHOD(Redis, sSize);
 PHP_METHOD(Redis, sRemove);
 PHP_METHOD(Redis, sMove);
@@ -103,15 +107,19 @@ PHP_METHOD(Redis, ttl);
 PHP_METHOD(Redis, pttl);
 PHP_METHOD(Redis, persist);
 PHP_METHOD(Redis, info);
-PHP_METHOD(Redis, resetStat);
 PHP_METHOD(Redis, select);
 PHP_METHOD(Redis, move);
 PHP_METHOD(Redis, zAdd);
 PHP_METHOD(Redis, zDelete);
 PHP_METHOD(Redis, zRange);
-PHP_METHOD(Redis, zReverseRange);
+PHP_METHOD(Redis, zRevRange);
 PHP_METHOD(Redis, zRangeByScore);
+PHP_METHOD(Redis, zRangeByLex);
 PHP_METHOD(Redis, zRevRangeByScore);
+PHP_METHOD(Redis, zRangeByLex);
+PHP_METHOD(Redis, zRevRangeByLex);
+PHP_METHOD(Redis, zRemRangeByLex);
+PHP_METHOD(Redis, zLexCount);
 PHP_METHOD(Redis, zCount);
 PHP_METHOD(Redis, zDeleteRangeByScore);
 PHP_METHOD(Redis, zDeleteRangeByRank);
@@ -134,11 +142,13 @@ PHP_METHOD(Redis, bitpos);
 PHP_METHOD(Redis, eval);
 PHP_METHOD(Redis, evalsha);
 PHP_METHOD(Redis, script);
+PHP_METHOD(Redis, debug);
 PHP_METHOD(Redis, dump);
 PHP_METHOD(Redis, restore);
 PHP_METHOD(Redis, migrate);
 
 PHP_METHOD(Redis, time);
+PHP_METHOD(Redis, role);
 
 PHP_METHOD(Redis, getLastError);
 PHP_METHOD(Redis, clearLastError);
@@ -187,7 +197,17 @@ PHP_METHOD(Redis, slowlog);
 PHP_METHOD(Redis, wait);
 PHP_METHOD(Redis, pubsub);
 
+/* Geoadd and friends */
+PHP_METHOD(Redis, geoadd);
+PHP_METHOD(Redis, geohash);
+PHP_METHOD(Redis, geopos);
+PHP_METHOD(Redis, geodist);
+PHP_METHOD(Redis, georadius);
+PHP_METHOD(Redis, georadiusbymember);
+
 PHP_METHOD(Redis, client);
+PHP_METHOD(Redis, command);
+PHP_METHOD(Redis, rawcommand);
 
 /* SCAN and friends  */
 PHP_METHOD(Redis, scan);
@@ -195,6 +215,11 @@ PHP_METHOD(Redis, hscan);
 PHP_METHOD(Redis, sscan);
 PHP_METHOD(Redis, zscan);
 
+/* HyperLogLog commands */
+PHP_METHOD(Redis, pfadd);
+PHP_METHOD(Redis, pfcount);
+PHP_METHOD(Redis, pfmerge);
+
 /* Reflection */
 PHP_METHOD(Redis, getHost);
 PHP_METHOD(Redis, getPort);
@@ -204,12 +229,7 @@ PHP_METHOD(Redis, getReadTimeout);
 PHP_METHOD(Redis, isConnected);
 PHP_METHOD(Redis, getPersistentID);
 PHP_METHOD(Redis, getAuth);
-
-#ifdef PHP_WIN32
-#define PHP_REDIS_API __declspec(dllexport)
-#else
-#define PHP_REDIS_API
-#endif
+PHP_METHOD(Redis, getMode);
 
 #ifdef ZTS
 #include "TSRM.h"
@@ -221,32 +241,35 @@ PHP_RINIT_FUNCTION(redis);
 PHP_RSHUTDOWN_FUNCTION(redis);
 PHP_MINFO_FUNCTION(redis);
 
-PHPAPI int redis_connect(INTERNAL_FUNCTION_PARAMETERS, int persistent);
-PHPAPI void redis_atomic_increment(INTERNAL_FUNCTION_PARAMETERS, char *keyword, int count);
-PHPAPI int generic_multiple_args_cmd(INTERNAL_FUNCTION_PARAMETERS, char *keyword, int keyword_len,
-									 int min_argc, RedisSock **redis_sock, int has_timeout, int all_keys, int can_serialize);
-PHPAPI void generic_sort_cmd(INTERNAL_FUNCTION_PARAMETERS, char *sort, int use_alpha);
-typedef void (*ResultCallback)(INTERNAL_FUNCTION_PARAMETERS, RedisSock *redis_sock, zval *z_tab, void *ctx);
-PHPAPI void generic_empty_cmd_impl(INTERNAL_FUNCTION_PARAMETERS, char *cmd, int cmd_len, ResultCallback result_callback);
-PHPAPI void generic_empty_cmd(INTERNAL_FUNCTION_PARAMETERS, char *cmd, int cmd_len, ...);
-PHPAPI void generic_empty_long_cmd(INTERNAL_FUNCTION_PARAMETERS, char *cmd, int cmd_len, ...);
+/* Redis response handler function callback prototype */
+typedef void (*ResultCallback)(INTERNAL_FUNCTION_PARAMETERS, 
+    RedisSock *redis_sock, zval *z_tab, void *ctx);
 
-PHPAPI void generic_subscribe_cmd(INTERNAL_FUNCTION_PARAMETERS, char *sub_cmd);
-PHPAPI void generic_unsubscribe_cmd(INTERNAL_FUNCTION_PARAMETERS, char *unsub_cmd);
+PHP_REDIS_API int redis_connect(INTERNAL_FUNCTION_PARAMETERS, int persistent);
 
-PHPAPI void array_zip_values_and_scores(RedisSock *redis_sock, zval *z_tab, int use_atof TSRMLS_DC);
-PHPAPI int redis_response_enqueued(RedisSock *redis_sock TSRMLS_DC);
+PHP_REDIS_API void generic_sort_cmd(INTERNAL_FUNCTION_PARAMETERS, char *sort, 
+    int use_alpha);
 
-PHPAPI int get_flag(zval *object TSRMLS_DC);
-PHPAPI void set_flag(zval *object, int new_flag TSRMLS_DC);
+PHP_REDIS_API void generic_subscribe_cmd(INTERNAL_FUNCTION_PARAMETERS, char *sub_cmd);
 
-PHPAPI int redis_sock_read_multibulk_multi_reply_loop(INTERNAL_FUNCTION_PARAMETERS, RedisSock *redis_sock, zval *z_tab, int numElems);
+PHP_REDIS_API void generic_unsubscribe_cmd(INTERNAL_FUNCTION_PARAMETERS, 
+    char *unsub_cmd);
+
+PHP_REDIS_API int redis_response_enqueued(RedisSock *redis_sock TSRMLS_DC);
+
+PHP_REDIS_API int get_flag(zval *object TSRMLS_DC);
+
+PHP_REDIS_API void set_flag(zval *object, int new_flag TSRMLS_DC);
+
+PHP_REDIS_API int redis_sock_read_multibulk_multi_reply_loop(
+    INTERNAL_FUNCTION_PARAMETERS, RedisSock *redis_sock, zval *z_tab, 
+    int numElems);
 
 /* pipeline */
-PHPAPI request_item* get_pipeline_head(zval *object);
-PHPAPI void set_pipeline_head(zval *object, request_item *head);
-PHPAPI request_item* get_pipeline_current(zval *object);
-PHPAPI void set_pipeline_current(zval *object, request_item *current);
+PHP_REDIS_API request_item* get_pipeline_head(zval *object);
+PHP_REDIS_API void set_pipeline_head(zval *object, request_item *head);
+PHP_REDIS_API request_item* get_pipeline_current(zval *object);
+PHP_REDIS_API void set_pipeline_current(zval *object, request_item *current);
 
 #ifndef _MSC_VER
 ZEND_BEGIN_MODULE_GLOBALS(redis)
@@ -254,23 +277,20 @@ ZEND_END_MODULE_GLOBALS(redis)
 #endif
 
 struct redis_queued_item {
+    /* reading function */
+    zval * (*fun)(INTERNAL_FUNCTION_PARAMETERS, RedisSock *redis_sock, ...);
 
-	/* reading function */
-	zval * (*fun)(INTERNAL_FUNCTION_PARAMETERS, RedisSock *redis_sock, ...);
+    char *cmd; 
+    int cmd_len;
 
-	char *cmd; 
-	int cmd_len;
-
-	struct redis_queued_item *next;
+    struct redis_queued_item *next;
 };
 
 extern zend_module_entry redis_module_entry;
+
 #define redis_module_ptr &redis_module_entry
-
 #define phpext_redis_ptr redis_module_ptr
 
-#define PHP_REDIS_VERSION "2.2.5"
-
 #endif
 
 /*
